@@ -8,21 +8,19 @@
 """
 """
 import sys
-from wavestate.pytest import ( # noqa
-    dprint, tpath_join, tpath, plot, fpath, capture
-)
+from wavestate.pytest import dprint, tpath_join, tpath, plot, fpath, capture  # noqa
 
 
 def test_pytest_tpath(tpath_join, fpath, dprint, capture):
-    with open(tpath_join('test.txt'), 'w') as f:
-        f.write('test\n')
+    with open(tpath_join("test.txt"), "w") as f:
+        f.write("test\n")
 
-    print('test output')
-    print('test output')
-    print('test output')
-    print('test output')
-    print('test output', file=sys.stderr)
-    print('test output')
-    print('test output')
-    print('test output' )
+    print("test output")
+    print("test output")
+    print("test output")
+    print("test output")
+    print("test output", file=sys.stderr)
+    print("test output")
+    print("test output")
+    print("test output")
     return
